summaryrefslogtreecommitdiffstats
path: root/kicker/kicker/ui/service_mnu.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kicker/kicker/ui/service_mnu.cpp')
-rw-r--r--kicker/kicker/ui/service_mnu.cpp38
1 files changed, 19 insertions, 19 deletions
diff --git a/kicker/kicker/ui/service_mnu.cpp b/kicker/kicker/ui/service_mnu.cpp
index 2d6287bb9..3042eddfe 100644
--- a/kicker/kicker/ui/service_mnu.cpp
+++ b/kicker/kicker/ui/service_mnu.cpp
@@ -230,8 +230,8 @@ void PanelServiceMenu::fillMenu(KServiceGroup::Ptr& _root,
TQString inlineHeaderName = g->showInlineHeader() ? groupCaption : "";
// Item names may contain ampersands. To avoid them being converted
- // to accelerators, tqreplace them with two ampersands.
- groupCaption.tqreplace("&", "&&");
+ // to accelerators, replace them with two ampersands.
+ groupCaption.replace("&", "&&");
if ( nbChildCount == 1 && g->allowInline() && g->inlineAlias())
{
@@ -411,7 +411,7 @@ void PanelServiceMenu::insertMenuItem(KService::Ptr & s, int nId,
if (KickerSettings::menuEntryFormat() == KickerSettings::NameAndDescription)
{
if ((!suppressGenericNames ||
- !suppressGenericNames->tqcontains(s->untranslatedGenericName())) &&
+ !suppressGenericNames->contains(s->untranslatedGenericName())) &&
serviceName.find(comment, 0, true) == -1)
{
if (comment.find(serviceName, 0, true) == -1)
@@ -449,8 +449,8 @@ void PanelServiceMenu::insertMenuItem(KService::Ptr & s, int nId,
return;
// item names may contain ampersands. To avoid them being converted
- // to accelerators, tqreplace them with two ampersands.
- serviceName.tqreplace("&", "&&");
+ // to accelerators, replace them with two ampersands.
+ serviceName.replace("&", "&&");
TQString icon = s->icon();
if (icon=="unknown")
@@ -544,7 +544,7 @@ bool PanelServiceMenu::highlightMenuItem( const TQString &menuItemId )
void PanelServiceMenu::slotExec(int id)
{
- if (!entryMap_.tqcontains(id))
+ if (!entryMap_.contains(id))
{
return;
}
@@ -578,7 +578,7 @@ void PanelServiceMenu::mouseReleaseEvent(TQMouseEvent * ev)
return;
}
- if (!entryMap_.tqcontains(id))
+ if (!entryMap_.contains(id))
{
kdDebug(1210) << "Cannot find service with menu id " << id << endl;
return;
@@ -695,7 +695,7 @@ void PanelServiceMenu::slotContextMenu(int selected)
case EditItem:
proc = new KProcess(this);
- *proc << KStandardDirs::findExe(TQString::tqfromLatin1("kmenuedit"));
+ *proc << KStandardDirs::findExe(TQString::fromLatin1("kmenuedit"));
*proc << "/"+relPath_ << static_cast<KService *>(contextKSycocaEntry_)->menuId();
proc->start();
break;
@@ -739,7 +739,7 @@ void PanelServiceMenu::slotContextMenu(int selected)
case EditMenu:
proc = new KProcess(this);
- *proc << KStandardDirs::findExe(TQString::tqfromLatin1("kmenuedit"));
+ *proc << KStandardDirs::findExe(TQString::fromLatin1("kmenuedit"));
*proc << "/"+static_cast<KServiceGroup *>(contextKSycocaEntry_)->relPath();
proc->start();
break;
@@ -769,7 +769,7 @@ void PanelServiceMenu::mouseMoveEvent(TQMouseEvent * ev)
if (id < serviceMenuStartId())
return;
- if (!entryMap_.tqcontains(id)) {
+ if (!entryMap_.contains(id)) {
kdDebug(1210) << "Cannot find service with menu id " << id << endl;
return;
}
@@ -838,7 +838,7 @@ void PanelServiceMenu::dragEnterEvent(TQDragEnterEvent *event)
void PanelServiceMenu::dragLeaveEvent(TQDragLeaveEvent *)
{
// see PanelServiceMenu::dragEnterEvent why this is nescessary
- if (!frameGeometry().tqcontains(TQCursor::pos()))
+ if (!frameGeometry().contains(TQCursor::pos()))
{
KURLDrag::setTarget(0);
}
@@ -932,12 +932,12 @@ void PanelServiceMenu::setSearchString(const TQString &searchString)
int id = *menuItemIt;
KService* s = dynamic_cast< KService* >( static_cast< KSycocaEntry* >( entryMap_[ id ]));
TQString menuText = text(id);
- if (menuText.tqcontains(searchString, false) > 0
- || ( s != NULL && ( s->name().tqcontains(searchString, false) > 0
- || s->exec().tqcontains(searchString, false) > 0
- || s->comment().tqcontains(searchString, false) > 0
- || s->genericName().tqcontains(searchString, false) > 0
- || s->exec().tqcontains(searchString, false) > 0 )
+ if (menuText.contains(searchString, false) > 0
+ || ( s != NULL && ( s->name().contains(searchString, false) > 0
+ || s->exec().contains(searchString, false) > 0
+ || s->comment().contains(searchString, false) > 0
+ || s->genericName().contains(searchString, false) > 0
+ || s->exec().contains(searchString, false) > 0 )
)) {
setItemEnabled(id, true);
foundSomething = true;
@@ -951,7 +951,7 @@ void PanelServiceMenu::setSearchString(const TQString &searchString)
/*for (int i=count()-1; i>=0; --i) {
int id = idAt(i);
TQString menuText = text(id);
- if (menuText.tqcontains(searchString, false) > 0) {
+ if (menuText.contains(searchString, false) > 0) {
setItemEnabled(id, true);
foundSomething = true;
nonemptyMenus.insert(id);
@@ -995,7 +995,7 @@ void PanelServiceMenu::updateRecentlyUsedApps(KService::Ptr &service)
TQString strItem(service->desktopEntryPath());
// don't add an item from root kmenu level
- if (!strItem.tqcontains('/'))
+ if (!strItem.contains('/'))
{
return;
}